<?php

namespace Ourgold\Exchange\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;

/**
 * Ourgold\Exchange\Models\ExchangeQueue
 *
 * @property int $id Внутренний ID
 * @property array $data Данные для обмена
 * @property int $status Статус обмена
 * @property string $error Описание ошибки
 * @property Carbon $created_at Дата создания
 * @property Carbon $updated_at Дата последнего обновления
 *
 * @method static Builder|ExchangeQueue query()
 * @method static Builder|ExchangeQueue unprocessed() Отбор по еще не выполненным запросам
 * @mixin \Eloquent
 * @SWG\Definition(
 *     definition="ExchangeQueue",
 *     description="Очередь обмена с внешними системами",
 *     type="object"
 * )
 * @SWG\Property(property="id", example="1")
 * @SWG\Property(property="data", example="{}")
 * @SWG\Property(property="status", example="1")
 * @SWG\Property(property="error", example="Описание ошибки")
 */
class ExchangeQueue extends Model
{
    protected $fillable = [
        'data',
        'status',
        'error',
    ];

    protected $casts = [
        'data' => 'array',
        'status' => 'boolean'
    ];

    /**
     * Отбор по еще не выполненным запросам
     * @param Builder $query
     * @return Builder
     */
    public function scopeUnprocessed(Builder $query): Builder
    {
        return $query->where('status', 0);
    }

    /**
     * @return string
     */
    public function getTable(): string
    {
        return config('exchange.table_name');
    }
}
